@@ -139,6 +139,8 @@ class AdalinaData:
         self.resources = resources
         self.resources_available = resources_available
         self.shelter_pair_properties = shelter_pair_properties
+        self.amelia_file_orig = None
+        self.user_input = None
 
         self.sfrom_to = None
         self.distance_facility_list = None
@@ -228,6 +230,10 @@ class AdalinaData:
         if "epsg" in user_input:
             epsg = user_input["epsg"]
 
+        amelia_file_orig = amelia_file.copy()
+        # id "ID" column must be a string
+        amelia_file[user_input["IDs"]] = [f"id : {el}" for el in amelia_file_orig[user_input["IDs"]]]
+
         areas = amelia_file[[user_input["IDs"],
                              user_input["demand"],
                              user_input["geometry"] ]].copy()
@@ -257,7 +263,11 @@ class AdalinaData:
         if "is_server" in user_input:
             shelter_cols.append(user_input["is_server"])
             shelter_col_rename[user_input["is_server"]] = "usable"
-        shelter_and_reources = amelia_file.loc[(amelia_file[user_input["demand"]].isna()) | (amelia_file[user_input["demand"]] < 1e-5)].copy()
+        shelter_and_reources = amelia_file.loc[
+            ((amelia_file[user_input["demand"]].isna()) | (amelia_file[user_input["demand"]] < 1e-5))
+            & ((amelia_file[[el["name"] for el in user_input["resources"]]] > 1e-5).any(axis=1))
+            ].copy()
+        #shelter_and_reources = amelia_file.loc[(amelia_file[user_input["demand"]].isna()) | (amelia_file[user_input["demand"]] < 1e-5)].copy()
 
         # shelter DF
         shelter = shelter_and_reources[shelter_cols].copy()
@@ -320,13 +330,18 @@ class AdalinaData:
         shelter_and_reources.set_index(keys=["shelter","resources"], inplace=True)
         shelter_pairs_properties.set_index(keys=["shelter_from", "shelter_to"], inplace=True)
 
-        return cls(areas,
+        obj =  cls(areas,
                    shelter,
                    area_shelter_pair_properties,
                    resources,
                    shelter_and_reources,
                    shelter_pairs_properties)
 
+        obj.amelia_file_orig = amelia_file_orig
+        obj.user_input = user_input
+
+        return obj
+
     @staticmethod
     def from_dataframe_to_geopandas(df : pd.DataFrame,
                                     epsg : EPSGFormats = EPSGFormats.EPSG4326,
