@@ -417,6 +417,9 @@ def get_solution_csv_AMELIA(sol: AdalinaSolution,
                             ):
     csv_out = pd.merge(data.areas.reset_index(), sol.areas.reset_index(), on = "area")
 
+    csv_out["area"] = [el[5:] for el in csv_out["area"]]
+    csv_out["area"] = csv_out["area"].astype(data.amelia_file_orig.dtypes[data.user_input["IDs"]])
+
     if epsg != EPSG_FORMAT_FOR_ALGORITHM:
         csv_out = csv_out.to_crs(epsg=epsg.value)
 
